@@ -39,7 +39,7 @@ public:
 
   virtual void bind(const cpp11::list& params);
 
-  virtual cpp11::writable::list get_column_info();
+  virtual cpp11::list get_column_info();
 
   virtual cpp11::list fetch(int n_max = -1);
 
